==> cngf-pf-0.6.2.tar.gz: cngf-pf-0.6.2/cngf-pf.c <==
#include <stdlib.h>
#include <math.h>
#include <string.h>
#include <time.h>
#include <unistd.h>
#include <err.h>

#include "simulation.h"
#include "fluid.h"

#include "arg.h"

/* relative tolerance criteria for granular fluidity solver */
#define RTOL 1e-5
#define MAX_ITER_1D_FD_SIMPLE_SHEAR 100000

/* uncomment to print time spent per time step to stdout */
/* #define BENCHMARK_PERFORMANCE */

char *argv0;

static void
usage(void)
{
	fprintf(stderr, "usage: %s "
	        "[-A grain-nonlocal-ampl] "
	        "[-a fluid-pressure-ampl] "
	        "[-b grain-rate-dependence] "
	        "[-C fluid-compressibility] "
	        "[-c grain-cohesion] "
	        "[-d grain-size] "
	        "[-D fluid-diffusivity] "
	        "[-e end-time] "
	        "[-F] "
	        "[-f applied-shear-friction] "
	        "[-g gravity-accel] "
	        "[-H fluid-pressure-phase] "
	        "[-h] "
	        "[-I file-interval] "
	        "[-i fluid-viscosity] "
	        "[-K dilatancy-constant] "
	        "[-k fluid-permeability] "
	        "[-L length] "
	        "[-l applied-shear-vel-limit] "
	        "[-m grain-friction] "
	        "[-N] "
	        "[-n normal-stress] "
	        "[-O fluid-pressure-top] "
	        "[-o origo] "
	        "[-P grain-compressibility] "
	        "[-p grain-porosity] "
	        "[-q fluid-pressure-freq] "
	        "[-R fluid-density] "
	        "[-r grain-density] "
	        "[-S fluid-pressure-pulse-shape] "
	        "[-s applied-shear-vel] "
	        "[-T] "
	        "[-t curr-time] "
	        "[-U resolution] "
	        "[-u fluid-pulse-time] "
	        "[-v] "
	        "[-Y max-porosity] "
	        "[-y min-porosity] "
	        "[name]\n", argv0);
	exit(1);
}

int
main(int argc, char *argv[])
{
	int i, normalize;
	unsigned long iter;
	double new_phi, new_k, filetimeclock;
	struct simulation sim;

#ifdef BENCHMARK_PERFORMANCE
	clock_t t_begin, t_end;
	double t_elapsed;

#endif

#ifdef __OpenBSD__
	if (pledge("stdio wpath cpath", NULL) == -1)
		err(2, "pledge failed");
#endif

	init_sim(&sim);
	normalize = 0;
	new_phi = sim.phi[0];
	new_k = sim.k[0];

	ARGBEGIN {
	case 'A':
		sim.A = atof(EARGF(usage()));
		break;
	case 'a':
		sim.p_f_mod_ampl = atof(EARGF(usage()));
		break;
	case 'b':
		sim.b = atof(EARGF(usage()));
		break;
	case 'C':
		sim.beta_f = atof(EARGF(usage()));
		break;
	case 'c':
		sim.C = atof(EARGF(usage()));
		break;
	case 'd':
		sim.d = atof(EARGF(usage()));
		break;
	case 'D':
		sim.D = atof(EARGF(usage()));
		break;
	case 'e':
		sim.t_end = atof(EARGF(usage()));
		break;
	case 'F':
		sim.fluid = 1;
		break;
	case 'f':
		sim.mu_wall = atof(EARGF(usage()));
		break;
	case 'g':
		sim.G = atof(EARGF(usage()));
		break;
	case 'H':
		sim.p_f_mod_phase = atof(EARGF(usage()));
		break;
	case 'h':
		usage();
		break;
	case 'I':
		sim.file_dt = atof(EARGF(usage()));
		break;
	case 'i':
		sim.mu_f = atof(EARGF(usage()));
		break;
	case 'K':
		sim.dilatancy_constant = atof(EARGF(usage()));
		break;
	case 'k':
		new_k = atof(EARGF(usage()));
		break;
	case 'L':
		sim.L_z = atof(EARGF(usage()));
		break;
	case 'l':
		sim.v_x_limit = atof(EARGF(usage()));
		break;
	case 'm':
		sim.mu_s = atof(EARGF(usage()));
		break;
	case 'N':
		normalize = 1;
		break;
	case 'n':
		sim.P_wall = atof(EARGF(usage()));
		break;
	case 'O':
		sim.p_f_top = atof(EARGF(usage()));
		break;
	case 'o':
		sim.origo_z = atof(EARGF(usage()));
		break;
	case 'P':
		sim.alpha = atof(EARGF(usage()));
		break;
	case 'p':
		new_phi = atof(EARGF(usage()));
		break;
	case 'q':
		sim.p_f_mod_freq = atof(EARGF(usage()));
		break;
	case 'R':
		sim.rho_f = atof(EARGF(usage()));
		break;
	case 'r':
		sim.rho_s = atof(EARGF(usage()));
		break;
	case 'S':
		if (argv[1] == NULL)
			usage();
		else if (!strncmp(argv[1], "triangle", 8))
			sim.p_f_mod_pulse_shape = 0;
		else if (!strncmp(argv[1], "square", 6))
			sim.p_f_mod_pulse_shape = 1;
		else {
			fprintf(stderr, "error: invalid pulse shape '%s'\n",
				argv[1]);
			return 1;
		}
		argc--;
		argv++;
		break;
	case 's':
		sim.v_x_fix = atof(EARGF(usage()));
		break;
	case 'T':
		sim.transient = 1;
		break;
	case 't':
		sim.t = atof(EARGF(usage()));
		break;
	case 'U':
		sim.nz = atoi(EARGF(usage()));
		break;
	case 'u':
		sim.p_f_mod_pulse_time = atof(EARGF(usage()));
		break;
	case 'V':
		sim.v_x_bot = atof(EARGF(usage()));
		break;
	case 'v':
		printf("%s-" VERSION "\n", argv0);
		return 0;
	case 'Y':
		sim.phi_max = atof(EARGF(usage()));
		break;
	case 'y':
		sim.phi_min = atof(EARGF(usage()));
		break;
	default:
		usage();
	} ARGEND;

	if (argc == 1 && argv[0])
		snprintf(sim.name, sizeof(sim.name), "%s", argv[0]);
	else if (argc > 1)
		usage();

	if (sim.nz < 1)
		sim.nz = (int) ceil(sim.L_z / sim.d);

	prepare_arrays(&sim);

	if (!isnan(new_phi))
		for (i = 0; i < sim.nz; ++i)
			sim.phi[i] = new_phi;
	if (!isnan(new_k))
		for (i = 0; i < sim.nz; ++i)
			sim.k[i] = new_k;

	lithostatic_pressure_distribution(&sim);

	if (sim.fluid) {
		hydrostatic_fluid_pressure_distribution(&sim);
		if (set_largest_fluid_timestep(&sim, 0.5)) {
			free_arrays(&sim);
			return 20;
		}
	}
	if (sim.dt > sim.file_dt)
		sim.dt = sim.file_dt;
	compute_effective_stress(&sim);

	check_simulation_parameters(&sim);

	filetimeclock = 0.0;
	iter = 0;
	do {

#ifdef BENCHMARK_PERFORMANCE
		t_begin = clock();
#endif

		if (coupled_shear_solver(&sim, MAX_ITER_1D_FD_SIMPLE_SHEAR, RTOL)) {
			free_arrays(&sim);
			exit(10);
		}
#ifdef BENCHMARK_PERFORMANCE
		t_end = clock();
		t_elapsed = (double) (t_end - t_begin) / CLOCKS_PER_SEC;
		printf("time spent per time step = %g s\n", t_elapsed);
#endif

		if ((filetimeclock >= sim.file_dt || iter == 1) &&
		    strncmp(sim.name, DEFAULT_SIMULATION_NAME,
		            sizeof(DEFAULT_SIMULATION_NAME)) != 0) {
			write_output_file(&sim, normalize);
			filetimeclock = 0.0;
		}
		filetimeclock += sim.dt;
		iter++;

	} while (sim.t - sim.dt < sim.t_end);

	print_output(&sim, stdout, normalize);

	free_arrays(&sim);
	return 0;
}

==> cngf-pf-0.7.0.tar.gz: cngf-pf-0.7.0/cngf-pf.c <==
#include <stdlib.h>
#include <math.h>
#include <string.h>
#include <time.h>
#include <unistd.h>
#include <err.h>

#include "simulation.h"
#include "fluid.h"

#include "arg.h"

/* relative tolerance criteria for the solvers */
#define RTOL 1e-5
#define MAX_ITER_1D_FD_SIMPLE_SHEAR 100000

/* uncomment to print time spent per time step to stdout */
/* #define BENCHMARK_PERFORMANCE */

char *argv0;

static void
usage(void)
{
	fprintf(stderr, "usage: %s "
	        "[-A grain-nonlocal-ampl] "
	        "[-a fluid-pressure-ampl] "
	        "[-b grain-rate-dependence] "
	        "[-C fluid-compressibility] "
	        "[-c grain-cohesion] "
	        "[-d grain-size] "
	        "[-D fluid-diffusivity] "
	        "[-e end-time] "
	        "[-F] "
	        "[-f applied-shear-friction] "
	        "[-g gravity-accel] "
	        "[-H fluid-pressure-phase] "
	        "[-h] "
	        "[-I file-interval] "
	        "[-i fluid-viscosity] "
	        "[-j time-step] "
	        "[-K dilatancy-constant] "
	        "[-k fluid-permeability] "
	        "[-L length] "
	        "[-l applied-shear-vel-limit] "
	        "[-m grain-friction] "
	        "[-N] "
	        "[-n normal-stress] "
	        "[-O fluid-pressure-top] "
	        "[-o origo] "
	        "[-P grain-compressibility] "
	        "[-p grain-porosity] "
	        "[-q fluid-pressure-freq] "
	        "[-R fluid-density] "
	        "[-r grain-density] "
	        "[-S fluid-pressure-pulse-shape] "
	        "[-s applied-shear-vel] "
	        "[-T] "
	        "[-t curr-time] "
	        "[-U resolution] "
	        "[-u fluid-pulse-time] "
	        "[-v] "
	        "[-Y max-porosity] "
	        "[-y min-porosity] "
	        "[name]\n", argv0);
	exit(1);
}

int
main(int argc, char *argv[])
{
	int i, normalize, dt_override, ret;
	unsigned long iter;
	double new_phi, new_k, filetimeclock;
	struct simulation sim;

#ifdef BENCHMARK_PERFORMANCE
	clock_t t_begin, t_end;
	double t_elapsed;
#endif

#ifdef __OpenBSD__
	if (pledge("stdio wpath cpath", NULL) == -1)
		err(2, "pledge failed");
#endif

	init_sim(&sim);
	normalize = 0;
	new_phi = sim.phi[0];
	new_k = sim.k[0];
	dt_override = 0;

	ARGBEGIN {
	case 'A':
		sim.A = atof(EARGF(usage()));
		break;
	case 'a':
		sim.p_f_mod_ampl = atof(EARGF(usage()));
		break;
	case 'b':
		sim.b = atof(EARGF(usage()));
		break;
	case 'C':
		sim.beta_f = atof(EARGF(usage()));
		break;
	case 'c':
		sim.C = atof(EARGF(usage()));
		break;
	case 'd':
		sim.d = atof(EARGF(usage()));
		break;
	case 'D':
		sim.D = atof(EARGF(usage()));
		break;
	case 'e':
		sim.t_end = atof(EARGF(usage()));
		break;
	case 'F':
		sim.fluid = 1;
		break;
	case 'f':
		sim.mu_wall = atof(EARGF(usage()));
		break;
	case 'g':
		sim.G = atof(EARGF(usage()));
		break;
	case 'H':
		sim.p_f_mod_phase = atof(EARGF(usage()));
		break;
	case 'h':
		usage();
		break;
	case 'I':
		sim.file_dt = atof(EARGF(usage()));
		break;
	case 'i':
		sim.mu_f = atof(EARGF(usage()));
		break;
	case 'j':
		sim.dt = atof(EARGF(usage()));
		dt_override = 1;
		break;
	case 'K':
		sim.dilatancy_constant = atof(EARGF(usage()));
		break;
	case 'k':
		new_k = atof(EARGF(usage()));
		break;
	case 'L':
		sim.L_z = atof(EARGF(usage()));
		break;
	case 'l':
		sim.v_x_limit = atof(EARGF(usage()));
		break;
	case 'm':
		sim.mu_s = atof(EARGF(usage()));
		break;
	case 'N':
		normalize = 1;
		break;
	case 'n':
		sim.P_wall = atof(EARGF(usage()));
		break;
	case 'O':
		sim.p_f_top = atof(EARGF(usage()));
		break;
	case 'o':
		sim.origo_z = atof(EARGF(usage()));
		break;
	case 'P':
		sim.alpha = atof(EARGF(usage()));
		break;
	case 'p':
		new_phi = atof(EARGF(usage()));
		break;
	case 'q':
		sim.p_f_mod_freq = atof(EARGF(usage()));
		break;
	case 'R':
		sim.rho_f = atof(EARGF(usage()));
		break;
	case 'r':
		sim.rho_s = atof(EARGF(usage()));
		break;
	case 'S':
		if (argv[1] == NULL)
			usage();
		else if (!strncmp(argv[1], "triangle", 8))
			sim.p_f_mod_pulse_shape = 0;
		else if (!strncmp(argv[1], "square", 6))
			sim.p_f_mod_pulse_shape = 1;
		else {
			fprintf(stderr, "error: invalid pulse shape '%s'\n",
				argv[1]);
			return 1;
		}
		argc--;
		argv++;
		break;
	case 's':
		sim.v_x_fix = atof(EARGF(usage()));
		break;
	case 'T':
		sim.transient = 1;
		break;
	case 't':
		sim.t = atof(EARGF(usage()));
		break;
	case 'U':
		sim.nz = atoi(EARGF(usage()));
		break;
	case 'u':
		sim.p_f_mod_pulse_time = atof(EARGF(usage()));
		break;
	case 'V':
		sim.v_x_bot = atof(EARGF(usage()));
		break;
	case 'v':
		printf("%s-" VERSION "\n", argv0);
		return 0;
	case 'Y':
		sim.phi_max = atof(EARGF(usage()));
		break;
	case 'y':
		sim.phi_min = atof(EARGF(usage()));
		break;
	default:
		usage();
	} ARGEND;

	if (argc == 1 && argv[0]) {
		ret = snprintf(sim.name, sizeof(sim.name), "%s", argv[0]);
		if (ret < 0 || (size_t)ret >= sizeof(sim.name))
			errx(1, "%s: could not write sim.name", __func__);
	} else if (argc > 1)
		usage();

	if (sim.nz < 1)
		sim.nz = (int) ceil(sim.L_z / sim.d);

	prepare_arrays(&sim);

	if (!isnan(new_phi))
		for (i = 0; i < sim.nz; ++i)
			sim.phi[i] = new_phi;
	if (!isnan(new_k))
		for (i = 0; i < sim.nz; ++i)
			sim.k[i] = new_k;

	lithostatic_pressure_distribution(&sim);

	if (sim.fluid) {
		hydrostatic_fluid_pressure_distribution(&sim);
		if (!dt_override) {
			if (set_largest_fluid_timestep(&sim, 0.5)) {
				free_arrays(&sim);
				return 20;
			}
			if (sim.transient)
			  set_coupled_fluid_transient_timestep(&sim, 0.5);
		}
	}
#ifdef DEBUG
	fprintf(stderr, "t_val = %g\n", sim.dt);
#endif

	if (sim.dt > sim.file_dt)
		sim.dt = sim.file_dt;
	if (sim.dt > sim.t_end)
		sim.dt = sim.t_end;
	compute_effective_stress(&sim);

	check_simulation_parameters(&sim);

	filetimeclock = 0.0;
	iter = 0;
	do {

#ifdef BENCHMARK_PERFORMANCE
		t_begin = clock();
#endif

		if (coupled_shear_solver(&sim, MAX_ITER_1D_FD_SIMPLE_SHEAR, RTOL)) {
			free_arrays(&sim);
			exit(10);
		}
#ifdef BENCHMARK_PERFORMANCE
		t_end = clock();
		t_elapsed = (double) (t_end - t_begin) / CLOCKS_PER_SEC;
		printf("time spent per time step = %g s\n", t_elapsed);
#endif

		if ((filetimeclock >= sim.file_dt || iter == 1) &&
		    strncmp(sim.name, DEFAULT_SIMULATION_NAME,
		            sizeof(DEFAULT_SIMULATION_NAME)) != 0) {
			write_output_file(&sim, normalize);
			filetimeclock = 0.0;
		}
		filetimeclock += sim.dt;
		iter++;

	} while (sim.t < sim.t_end);

	print_output(&sim, stdout, normalize);

	free_arrays(&sim);
	return 0;
}
